import events
import turn
from mediator import mediator
import spinny_arrow
import pygame

# all these have to be a multiple of 5 or it will
# mess up the tornado cost calculations
MAX_FAITH_POINTS = 2000
INITIAL_FAITH_POINTS = 1000

TERRAFORM_COST = 20
TORNADO_COST_MULT = 10

AVATAR_POS0 = pygame.Rect(40, 390, 40, 40)
AVATAR_POS1 = pygame.Rect(720, 390, 40, 40)

class Player(object):
    """
    Player state container
    """
    def __init__(self, name, colour):
        self.name = name
        self.colour = colour
        self.village = None
        self._faithPoints = INITIAL_FAITH_POINTS
        self._image = None
        self.rect = None
        mediator.addListener("terrain.alter", self.terraform_faith_adjust)
        mediator.addListener("tornado.added", self.tornado_faith_adjust)
        
        if(name=="Monkey"):
            self._image = pygame.image.load("data/Monkey.png")
            self.rect = AVATAR_POS0
        else:
            self._image = pygame.image.load("data/Cow.png")
            self.rect = AVATAR_POS1

    def terraform_faith_adjust(self, event):
        if(turn.current_turn.player == self):
            self.faith -= TERRAFORM_COST

    def tornado_faith_adjust(self, event):
        if(turn.current_turn.player == self):
            before_pts = self.faith
            cost = event.radius * TORNADO_COST_MULT 
            self.faith -= cost 
            print "Before-Faith: %s, After-Faith %s, Cost:%s\n" %(before_pts, self.faith, cost)

            
    def huts():
        doc = "Huts in this players village"
        def fget(self):
            huts = []
            if (self.village is not None):
                huts = self.village.huts
            return huts
        return locals() 
    huts = property(**huts())
    
    def health():
        doc = "Sum of the health of all a player's huts"
        def fget(self):
            if (self.village is not None):
                return self.village.health 
            else:
                return 0
        return locals()
    health = property(**health())

    def faith():
        doc = "The amount of faith the player has"
        def fget(self):
            return self._faithPoints
        def fset(self, value):
            print "*************Adjusting %s's faith to: %s" %(self.name, value)
            
            self._faithPoints = value
            if(value < 0):
                self._faithPoints = 0
                print "Publish next turn - player.py"
                mediator.publishEvent("next_turn")
            mediator.publishEvent(events.PLAYER_FAITH_ADJUSTED, player=self, value=value)
        return locals()
    faith = property(**faith())


    def getMaxTornadoPoints(self):
        """Determines if the 'add tornado' button should be shown"""
        cost = 0
        if(turn.current_turn.player == self):
            cost = (self.faith) - (spinny_arrow.MIN_INCR * TORNADO_COST_MULT)
            if (cost < 0):
                cost = 0
        return cost
    
    def getMinTornadoPoints(self):
        """Determines the max radius of the tornado"""
        cost = 0
        if(turn.current_turn.player == self):
            cost = (self.faith) / TORNADO_COST_MULT - spinny_arrow.MIN_INCR
            if (cost < spinny_arrow.MIN_INCR):
                cost = spinny_arrow.MIN_INCR

        return cost
    
    def image():
        doc = "The foo property."
        def fget(self):
            return self._image
        return locals()
    image = property(**image())
          

player0 = Player("Monkey", (255,128,128))
player1 = Player("Cow", (255,255,128))

def resetFaithPoints():
    player0._faithPoints = INITIAL_FAITH_POINTS
    player1._faithPoints = INITIAL_FAITH_POINTS

players = (player0, player1)
