import sys
import os

libdir = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
sys.path.insert(0, libdir)

import pygame
from pygame.locals import *
from pgu import text, gui as pgui

MIN_INCR = 10

def load_image(name, colorkey=None):
    fullname = os.path.join('data', name)
    try:
        image = pygame.image.load(fullname)
    except pygame.error, message:
        print 'Cannot load image:', fullname
        raise SystemExit, message
    image = image.convert()
    if colorkey is not None:
        if colorkey is -1:
            colorkey = image.get_at((0,0))
        image.set_colorkey(colorkey, RLEACCEL)
    return image, image.get_rect()

class Arrow(pygame.sprite.Sprite):
    """moves a monkey critter across the screen. it can spin the
       monkey when it is punched."""
    def __init__(self):
        pygame.sprite.Sprite.__init__(self)
        self.image, self.rect = load_image('arrow.png', -1)
        
        screen = pygame.display.get_surface()
        self.area = screen.get_rect()
        
        self.original = self.image

        self.rect.topleft = 0,0
        self.angle = 0
        self.last_pos = [0,0]
        self.curr_incr = MIN_INCR
        self.move((self.area.width/2,self.area.height/2))

        self.alive = 0
        
    def update(self):
        rect = self.rect
        image = self.image
        
    def spin(self):
        "spin the arrow"
        if (self.alive == 0):
            return
        
        center = self.rect.center
        self.angle += 12
        if self.angle >= 360:
            self.angle = 0
            self.image = self.original
        else:
            rotate = pygame.transform.rotate
            self.image = rotate(self.original, self.angle)
        self.rect = self.image.get_rect(center=center)

    def clicked(self, pos):
        if (self.alive == 0):
            return False
        
        return self.rect.collidepoint(pos)

    def move(self,pos):
        if (self.alive == 0):
            return
        
        self.rect = pygame.Rect(pos[0] - self.rect.width/2, pos[1] - self.rect.height/2, self.rect.width, self.rect.height)
        self.last_pos = pos
        return

    def resize(self, args, max_size):
        if (self.alive == 0):
            return
        
        incr = 0
        incr_x = args[0]
        incr_y = args[1]
        
        if (incr_x > incr_y):
            incr = incr_x
        else:
            incr = incr_y

        if (incr < -40):
            return
        if (incr > 40):
            return

        # make sure multiple of 5
        incr = int(incr) / 5 * 5
        
        self.curr_incr += incr

        if (self.curr_incr < MIN_INCR):
            self.curr_incr = MIN_INCR
        if (self.curr_incr > 50):
            self.curr_incr = 50

        if (self.curr_incr > max_size):
            self.curr_incr = max_size

        self.image, self.rect = load_image('arrow.png', -1)
        self.image = pygame.transform.scale(self.image, (self.rect.width + self.curr_incr - MIN_INCR,
                                                         self.rect.height + self.curr_incr - MIN_INCR ))
        self.original = self.image

        self.rect = pygame.Rect(self.last_pos[0] - self.rect.width/2,
                                self.last_pos[1] - self.rect.height/2, self.rect.width, self.rect.height)

        center = self.rect.center
        rotate = pygame.transform.rotate
        self.image = rotate(self.original, self.angle)
        self.rect = self.image.get_rect(center=center)

    def getRadius(self):
        return self.curr_incr
